@@ -115,7 +115,12 @@ class IVector:
         if not (isinstance(other, float) or isinstance(other, int)):
             raise TypeError(f"Object of type [{type(other)}] cannot be divided from {type(self)}")
 
-        return self.unit() * self.length() / other
+        new_vector = self.unit()
+        for ii in new_vector.coords:
+            new_vector.coords[ii] = new_vector.coords[ii] * (self.length() / other)
+
+        return new_vector
+        # return self.unit() * self.length() / other
 
 
     def _is_close(self, a:float, b:float, rel_tol=1e-09, abs_tol=0.0):
